summaryrefslogtreecommitdiffstats
path: root/bin/df/df.c
diff options
context:
space:
mode:
authortrhodes <trhodes@FreeBSD.org>2002-08-21 17:32:44 +0000
committertrhodes <trhodes@FreeBSD.org>2002-08-21 17:32:44 +0000
commit9618da3e35435c433d8086d65af15f716ffe32ec (patch)
tree170fdd70317f0e6648584759afc92e4021ebcd92 /bin/df/df.c
parent34ae8fe5374af25df8e04d804f045ed309399984 (diff)
downloadFreeBSD-src-9618da3e35435c433d8086d65af15f716ffe32ec.zip
FreeBSD-src-9618da3e35435c433d8086d65af15f716ffe32ec.tar.gz
s/filesystem/file system/ as discussed on -developers
Diffstat (limited to 'bin/df/df.c')
-rw-r--r--bin/df/df.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/bin/df/df.c b/bin/df/df.c
index 9bb5204..ae15cf2 100644
--- a/bin/df/df.c
+++ b/bin/df/df.c
@@ -289,8 +289,8 @@ getmntpt(char *name)
}
/*
* Make a pass over the filesystem info in ``mntbuf'' filtering out
* filesystem types not in vfslist and possibly re-stating to get
* current (not cached) info. Returns the new count of valid statfs bufs.
*/
static long
@@ -367,15 +367,15 @@ prthumanval(double bytes)
}
/*
* Convert statfs returned filesystem size into BLOCKSIZE units.
* Attempts to avoid overflow for large filesystems.
*/
#define fsbtoblk(num, fsbs, bs) \
(((fsbs) != 0 && (fsbs) < (bs)) ? \
(num) / ((bs) / (fsbs)) : (num) * ((fsbs) / (bs)))
/*
* Print out status about a filesystem.
*/
static void
prtstat(struct statfs *sfsp, struct maxwidths *mwp)
@@ -435,7 +435,7 @@ prtstat(struct statfs *sfsp, struct maxwidths *mwp)
/*
* Update the maximum field-width information in `mwp' based on
* the filesystem specified by `sfsp'.
*/
static void
update_maxwidths(struct maxwidths *mwp, struct statfs *sfsp)
@@ -483,7 +483,7 @@ usage(void)
{
(void)fprintf(stderr,
- "usage: df [-b | -H | -h | -k | -m | -P] [-ailn] [-t type] [file | filesystem ...]\n");
+ "usage: df [-b | -H | -h | -k | -m | -P] [-ailn] [-t type] [file | file system ...]\n");
exit(EX_USAGE);
}
OpenPOWER on IntegriCloud
@@ -289,8 +289,8 @@ getmntpt(char *name)
}
/*
- * Make a pass over the filesystem info in ``mntbuf'' filtering out
- * filesystem types not in vfslist and possibly re-stating to get
+ * Make a pass over the file system info in ``mntbuf'' filtering out
+ * file system types not in vfslist and possibly re-stating to get
* current (not cached) info. Returns the new count of valid statfs bufs.
*/
@@ -367,15 +367,15 @@ prthumanval(double bytes)
}
/*
- * Convert statfs returned filesystem size into BLOCKSIZE units.
- * Attempts to avoid overflow for large filesystems.
+ * Convert statfs returned file system size into BLOCKSIZE units.
+ * Attempts to avoid overflow for large file systems.
*/
#define fsbtoblk(num, fsbs, bs) \
@@ -367,15 +367,15 @@ prthumanval(double bytes)
(num) / ((bs) / (fsbs)) : (num) * ((fsbs) / (bs)))
/*
- * Print out status about a filesystem.
+ * Print out status about a file system.
*/
static void
@@ -435,7 +435,7 @@ prtstat(struct statfs *sfsp, struct maxwidths *mwp)
/*
* Update the maximum field-width information in `mwp' based on
- * the filesystem specified by `sfsp'.
+ * the file system specified by `sfsp'.
*/
static void